@@ -1,27 +1,30 @@
-use log::{trace};
+use log::trace;
 
 use crate::{
-  dds::values::result::*,
-  dds::traits::key::*,
+  dds::{traits::key::*, values::result::*},
   messages::submessages::submessage_elements::{
     parameter_list::ParameterList, RepresentationIdentifier,
   },
-  structure::{parameter_id::ParameterId, inline_qos::StatusInfo},
+  structure::{inline_qos::StatusInfo, parameter_id::ParameterId},
 };
 
-// This is to be implemented by all DomanParticipant, Publisher, Subscriber, DataWriter, DataReader, Topic
-/// Trait that is implemented by all necessary DDS Entities that are required to provide QosPolicies.
+// This is to be implemented by all DomanParticipant, Publisher, Subscriber,
+// DataWriter, DataReader, Topic
+/// Trait that is implemented by all necessary DDS Entities that are required to
+/// provide QosPolicies.
 pub trait HasQoSPolicy {
-  fn get_qos(&self) -> QosPolicies;
+  fn qos(&self) -> QosPolicies;
 }
 
-/// Trait that is implemented by all necessary DDS Entities that are required to have a mutable QosPolicies.
+/// Trait that is implemented by all necessary DDS Entities that are required to
+/// have a mutable QosPolicies.
 pub trait MutQosPolicy {
   fn set_qos(&mut self, new_qos: &QosPolicies) -> Result<()>;
 }
 
 /// DDS spec 2.3.3 defines this as "long" with named constants from 0 to 22.
-/// numbering is from IDL PSM, but it should be unnecessary at the Rust application interface
+/// numbering is from IDL PSM, but it should be unnecessary at the Rust
+/// application interface
 #[derive(Copy, Clone, PartialEq, Eq, PartialOrd, Ord, Debug)]
 pub enum QosPolicyId {
   //Invalid  // We should represent this using Option<QosPolicyId> where needed
@@ -50,6 +53,7 @@ pub enum QosPolicyId {
 }
 
 /// Utility for building [QosPolicies](struct.QosPolicies.html)
+#[derive(Default)]
 pub struct QosPolicyBuilder {
   durability: Option<policy::Durability>,
   presentation: Option<policy::Presentation>,
@@ -66,21 +70,8 @@ pub struct QosPolicyBuilder {
 }
 
 impl QosPolicyBuilder {
-  pub const fn new() -> QosPolicyBuilder {
-    QosPolicyBuilder {
-      durability: None,
-      presentation: None,
-      deadline: None,
-      latency_budget: None,
-      ownership: None,
-      liveliness: None,
-      time_based_filter: None,
-      reliability: None,
-      destination_order: None,
-      history: None,
-      resource_limits: None,
-      lifespan: None,
-    }
+  pub fn new() -> QosPolicyBuilder {
+    Self::default()
   }
 
   pub const fn durability(mut self, durability: policy::Durability) -> QosPolicyBuilder {
@@ -171,7 +162,7 @@ impl QosPolicyBuilder {
 }
 
 /// Describes single RTPS/DDS QoS policy
-#[derive(Clone, Debug, PartialEq, Eq)]
+#[derive(Clone, Debug, PartialEq, Eq, Default)]
 pub struct QosPolicies {
   // pub(crate) beacuse as we want to have some builtin QoS Policies as constant.
   pub(crate) durability: Option<policy::Durability>,
@@ -190,24 +181,11 @@ pub struct QosPolicies {
 
 impl QosPolicies {
   // #[cfg(test)]
-  pub const fn qos_none() -> QosPolicies {
-    QosPolicies {
-      durability: None,
-      presentation: None,
-      deadline: None,
-      latency_budget: None,
-      ownership: None,
-      liveliness: None,
-      time_based_filter: None,
-      reliability: None,
-      destination_order: None,
-      history: None,
-      resource_limits: None,
-      lifespan: None,
-    }
+  pub fn qos_none() -> QosPolicies {
+    Self::default()
   }
 
-  pub const fn builder() -> QosPolicyBuilder {
+  pub fn builder() -> QosPolicyBuilder {
     QosPolicyBuilder::new()
   }
 
@@ -386,13 +364,16 @@ impl QosPolicies {
   }
 }
 
-// put these into a submodule to avoid repeating the word "policy" or "qospolicy"
+// put these into a submodule to avoid repeating the word "policy" or
+// "qospolicy"
 /// Contains all available QoSPolicies
 pub mod policy {
-  use crate::structure::{parameter_id::ParameterId, duration::Duration};
-  use serde::{Serialize, Deserialize};
   use std::cmp::Ordering;
 
+  use serde::{Deserialize, Serialize};
+
+  use crate::structure::{duration::Duration, parameter_id::ParameterId};
+
   /*
   pub struct UserData {
     pub value: Vec<u8>,
@@ -663,7 +644,8 @@ impl InlineQos {
   }
 }
 
-// TODO: helper function to check is a QosPolices object is inconsistent (by itself)
+// TODO: helper function to check is a QosPolices object is inconsistent (by
+// itself)
 
 // TODO: helper function to check if two QosPolicies: Reequested and Offered are
 // compatible, according to DDS spec 2.2.3
