@@ -1,4 +1,4 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 use cdr_encoding_size::*;
 
 use crate::{
@@ -7,7 +7,9 @@ use crate::{
 };
 
 /// Analog of DDS GUID in ROS2 builtin datastructures
-#[derive(Debug, Copy, Clone, PartialEq, Eq, Hash, PartialOrd, Ord, Serialize, Deserialize, CdrEncodingSize,)]
+#[derive(
+  Debug, Copy, Clone, PartialEq, Eq, Hash, PartialOrd, Ord, Serialize, Deserialize, CdrEncodingSize,
+)]
 pub struct Gid {
   data: [u8; 24],
 }
@@ -43,11 +45,11 @@ impl NodeInfo {
     }
   }
 
-  pub fn get_namespace(&self) -> &str {
+  pub fn namespace(&self) -> &str {
     &self.node_namespace
   }
 
-  pub fn get_name(&self) -> &str {
+  pub fn name(&self) -> &str {
     &self.node_name
   }
 
@@ -160,7 +162,7 @@ impl Log {
   }
 
   /// Name of the rosout message
-  pub fn get_name(&self) -> &str {
+  pub fn name(&self) -> &str {
     &self.name
   }
 
