@@ -1,34 +1,34 @@
-use std::collections::{HashMap, HashSet};
-use std::sync::{Arc, Mutex};
+use std::{
+  collections::{HashMap, HashSet},
+  sync::{Arc, Mutex},
+};
+
 use log::{error, info};
 use mio::Evented;
-use serde::{Serialize, de::DeserializeOwned};
+use serde::{de::DeserializeOwned, Serialize};
 
 use crate::{
   dds::{
+    data_types::DiscoveredTopicData,
     no_key::{
       datareader::DataReader as NoKeyDataReader, datawriter::DataWriter as NoKeyDataWriter,
     },
-    DomainParticipant,
-    pubsub::Publisher,
-    pubsub::Subscriber,
+    pubsub::{Publisher, Subscriber},
     qos::QosPolicies,
     topic::{Topic, TopicKind},
-    traits::key::Key,
-    traits::key::Keyed,
-    traits::serde_adapters::*,
+    traits::{
+      key::{Key, Keyed},
+      serde_adapters::*,
+    },
     values::result::Error,
-    data_types::DiscoveredTopicData,
+    DomainParticipant,
   },
   structure::{entity::RTPSEntity, guid::GUID},
 };
-
 use super::{
+  builtin_datatypes::{Gid, Log, NodeInfo, ParameterEvents, ROSParticipantInfo},
+  builtin_topics::{ParameterEventsTopic, ROSDiscoveryTopic, RosOutTopic},
   KeyedRosPublisher, KeyedRosSubscriber, RosPublisher, RosSubscriber,
-  builtin_datatypes::NodeInfo,
-  builtin_datatypes::{Gid, Log, ParameterEvents, ROSParticipantInfo},
-  builtin_topics::ParameterEventsTopic,
-  builtin_topics::{ROSDiscoveryTopic, RosOutTopic},
 };
 
 // ----------------------------------------------------------------------------------------------------
@@ -36,7 +36,8 @@ use super::{
 // ----------------------------------------------------------------------------------------------------
 // ----------------------------------------------------------------------------------------------------
 
-/// [RosParticipant](struct.RosParticipant.html) sends and receives other participants information in ROS2 network
+/// [RosParticipant](struct.RosParticipant.html) sends and receives other
+/// participants information in ROS2 network
 #[derive(Clone)]
 pub struct RosParticipant {
   inner: Arc<Mutex<RosParticipantInner>>,
@@ -76,8 +77,8 @@ impl RosParticipant {
     self.inner.lock().unwrap().domain_participant.domain_id()
   }
 
-  pub fn get_discovered_topics(&self) -> Vec<DiscoveredTopicData> {
-    self.domain_participant().get_discovered_topics()
+  pub fn discovered_topics(&self) -> Vec<DiscoveredTopicData> {
+    self.domain_participant().discovered_topics()
   }
 
   pub fn add_node_info(&mut self, node_info: NodeInfo) {
@@ -137,26 +138,25 @@ impl RosParticipantInner {
     let ros_discovery_topic = domain_participant.create_topic(
       ROSDiscoveryTopic::topic_name().to_string(),
       ROSDiscoveryTopic::type_name().to_string(),
-      &ROSDiscoveryTopic::get_qos(),
+      &ROSDiscoveryTopic::qos(),
       TopicKind::NoKey,
     )?;
 
-    let ros_discovery_publisher =
-      domain_participant.create_publisher(&ROSDiscoveryTopic::get_qos())?;
+    let ros_discovery_publisher = domain_participant.create_publisher(&ROSDiscoveryTopic::qos())?;
     let ros_discovery_subscriber =
-      domain_participant.create_subscriber(&ROSDiscoveryTopic::get_qos())?;
+      domain_participant.create_subscriber(&ROSDiscoveryTopic::qos())?;
 
     let ros_parameter_events_topic = domain_participant.create_topic(
       ParameterEventsTopic::topic_name().to_string(),
       ParameterEventsTopic::type_name().to_string(),
-      &ParameterEventsTopic::get_qos(),
+      &ParameterEventsTopic::qos(),
       TopicKind::NoKey,
     )?;
 
     let ros_rosout_topic = domain_participant.create_topic(
       RosOutTopic::topic_name().to_string(),
       RosOutTopic::type_name().to_string(),
-      &RosOutTopic::get_qos(),
+      &RosOutTopic::qos(),
       TopicKind::NoKey,
     )?;
 
@@ -184,15 +184,15 @@ impl RosParticipantInner {
   /// Gets our current participant info we have sent to ROS2 network
   pub fn get_ros_participant_info(&self) -> ROSParticipantInfo {
     ROSParticipantInfo::new(
-      Gid::from_guid(self.domain_participant.get_guid()),
+      Gid::from_guid(self.domain_participant.guid()),
       self.nodes.iter().map(|(_, p)| p.clone()).collect(),
     )
   }
 
   // Adds new NodeInfo and updates our RosParticipantInfo to ROS2 network
   fn add_node_info(&mut self, mut node_info: NodeInfo) {
-    node_info.add_reader(Gid::from_guid(self.node_reader.get_guid()));
-    node_info.add_writer(Gid::from_guid(self.node_writer.get_guid()));
+    node_info.add_reader(Gid::from_guid(self.node_reader.guid()));
+    node_info.add_writer(Gid::from_guid(self.node_writer.guid()));
 
     self.nodes.insert(node_info.get_full_name(), node_info);
     self.broadcast_node_infos();
@@ -291,7 +291,7 @@ impl NodeOptions {
   /// # Arguments
   ///
   /// * `enable_rosout` -  Wheter or not ros logging is enabled (rosout writer)
-  pub fn new(/*domain_id: u16, */ enable_rosout: bool) -> NodeOptions {
+  pub fn new(/* domain_id: u16, */ enable_rosout: bool) -> NodeOptions {
     NodeOptions { enable_rosout }
   }
 }
@@ -301,8 +301,9 @@ impl NodeOptions {
 // ----------------------------------------------------------------------------------------------------
 // ----------------------------------------------------------------------------------------------------
 
-/// Node in ROS2 network. Holds necessary readers and writers for rosout and parameter events topics internally.
-/// Should be constructed using [builder](struct.RosNodeBuilder.html).
+/// Node in ROS2 network. Holds necessary readers and writers for rosout and
+/// parameter events topics internally. Should be constructed using
+/// [builder](struct.RosNodeBuilder.html).
 pub struct RosNode {
   // node info
   name: String,
@@ -362,9 +363,9 @@ impl RosNode {
   fn generate_node_info(&self) -> NodeInfo {
     let mut node_info = NodeInfo::new(self.name.to_owned(), self.namespace.to_owned());
 
-    node_info.add_writer(Gid::from_guid(self.parameter_events_writer.get_guid()));
+    node_info.add_writer(Gid::from_guid(self.parameter_events_writer.guid()));
     if let Some(row) = &self.rosout_writer {
-      node_info.add_writer(Gid::from_guid(row.get_guid()))
+      node_info.add_writer(Gid::from_guid(row.guid()))
     }
 
     for reader in self.readers.iter() {
@@ -415,11 +416,11 @@ impl RosNode {
       .add_node_info(self.generate_node_info());
   }
 
-  pub fn get_name(&self) -> &str {
+  pub fn name(&self) -> &str {
     &self.name
   }
 
-  pub fn get_namespace(&self) -> &str {
+  pub fn namespace(&self) -> &str {
     &self.namespace
   }
 
@@ -441,26 +442,32 @@ impl RosNode {
   ///
   /// # Arguments
   ///
-  /// * `domain_participant` - [DomainParticipant](../dds/struct.DomainParticipant.html)
+  /// * `domain_participant` -
+  ///   [DomainParticipant](../dds/struct.DomainParticipant.html)
   /// * `name` - Name of the topic
   /// * `type_name` - What type the topic holds in string form
-  /// * `qos` - Quality of Service parameters for the topic (not restricted only to ROS2)
-  /// * `topic_kind` - Does the topic have a key (multiple DDS instances)? NoKey or WithKey
+  /// * `qos` - Quality of Service parameters for the topic (not restricted only
+  ///   to ROS2)
+  /// * `topic_kind` - Does the topic have a key (multiple DDS instances)? NoKey
+  ///   or WithKey
   ///
   ///  
   ///   [summary of all rules for topic and service names in ROS 2](https://design.ros2.org/articles/topic_and_service_names.html)
   ///   (as of Dec 2020)
   ///
   /// * must not be empty
-  /// * may contain alphanumeric characters ([0-9|a-z|A-Z]), underscores (_), or forward slashes (/)
+  /// * may contain alphanumeric characters ([0-9|a-z|A-Z]), underscores (_), or
+  ///   forward slashes (/)
   /// * may use balanced curly braces ({}) for substitutions
   /// * may start with a tilde (~), the private namespace substitution character
   /// * must not start with a numeric character ([0-9])
   /// * must not end with a forward slash (/)
   /// * must not contain any number of repeated forward slashes (/)
   /// * must not contain any number of repeated underscores (_)
-  /// * must separate a tilde (~) from the rest of the name with a forward slash (/), i.e. ~/foo not ~foo
-  /// * must have balanced curly braces ({}) when used, i.e. {sub}/foo but not {sub/foo nor /foo}
+  /// * must separate a tilde (~) from the rest of the name with a forward slash
+  ///   (/), i.e. ~/foo not ~foo
+  /// * must have balanced curly braces ({}) when used, i.e. {sub}/foo but not
+  ///   {sub/foo nor /foo}
   pub fn create_ros_topic(
     &self,
     name: &str,
@@ -490,7 +497,8 @@ impl RosNode {
   /// # Arguments
   ///
   /// * `topic` - Reference to topic created with `create_ros_topic`.
-  /// * `qos` - Should take [QOS](../dds/qos/struct.QosPolicies.html) and use if it's compatible with topics QOS. `None` indicates the use of Topics QOS.
+  /// * `qos` - Should take [QOS](../dds/qos/struct.QosPolicies.html) and use if
+  ///   it's compatible with topics QOS. `None` indicates the use of Topics QOS.
   pub fn create_ros_nokey_subscriber<
     D: DeserializeOwned + 'static,
     DA: no_key::DeserializerAdapter<D>,
@@ -503,7 +511,7 @@ impl RosNode {
       .ros_participant
       .get_ros_discovery_subscriber()
       .create_datareader_no_key::<D, DA>(topic, qos)?;
-    self.add_reader(sub.get_guid());
+    self.add_reader(sub.guid());
     Ok(sub)
   }
 
@@ -512,7 +520,9 @@ impl RosNode {
   /// # Arguments
   ///
   /// * `topic` - Reference to topic created with `create_ros_topic`.
-  /// * `qos` - Should take [QOS](../dds/qos/struct.QosPolicies.html) and use it if it's compatible with topics QOS. `None` indicates the use of Topics QOS.
+  /// * `qos` - Should take [QOS](../dds/qos/struct.QosPolicies.html) and use it
+  ///   if it's compatible with topics QOS. `None` indicates the use of Topics
+  ///   QOS.
   pub fn create_ros_subscriber<D, DA: with_key::DeserializerAdapter<D>>(
     &mut self,
     topic: Topic,
@@ -526,7 +536,7 @@ impl RosNode {
       .ros_participant
       .get_ros_discovery_subscriber()
       .create_datareader::<D, DA>(topic, qos)?;
-    self.add_reader(sub.get_guid());
+    self.add_reader(sub.guid());
     Ok(sub)
   }
 
@@ -535,7 +545,9 @@ impl RosNode {
   /// # Arguments
   ///
   /// * `topic` - Reference to topic created with `create_ros_topic`.
-  /// * `qos` - Should take [QOS](../dds/qos/struct.QosPolicies.html) and use it if it's compatible with topics QOS. `None` indicates the use of Topics QOS.
+  /// * `qos` - Should take [QOS](../dds/qos/struct.QosPolicies.html) and use it
+  ///   if it's compatible with topics QOS. `None` indicates the use of Topics
+  ///   QOS.
   pub fn create_ros_nokey_publisher<D: Serialize, SA: no_key::SerializerAdapter<D>>(
     &mut self,
     topic: Topic,
@@ -545,7 +557,7 @@ impl RosNode {
       .ros_participant
       .get_ros_discovery_publisher()
       .create_datawriter_no_key(topic, qos)?;
-    self.add_writer(p.get_guid());
+    self.add_writer(p.guid());
     Ok(p)
   }
 
@@ -554,7 +566,9 @@ impl RosNode {
   /// # Arguments
   ///
   /// * `topic` - Reference to topic created with `create_ros_topic`.
-  /// * `qos` - Should take [QOS](../dds/qos/struct.QosPolicies.html) and use it if it's compatible with topics QOS. `None` indicates the use of Topics QOS.
+  /// * `qos` - Should take [QOS](../dds/qos/struct.QosPolicies.html) and use it
+  ///   if it's compatible with topics QOS. `None` indicates the use of Topics
+  ///   QOS.
   pub fn create_ros_publisher<D, SA: with_key::SerializerAdapter<D>>(
     &mut self,
     topic: Topic,
@@ -568,7 +582,7 @@ impl RosNode {
       .ros_participant
       .get_ros_discovery_publisher()
       .create_datawriter(topic, qos)?;
-    self.add_writer(p.get_guid());
+    self.add_writer(p.guid());
     Ok(p)
   }
 }
