@@ -1,39 +1,42 @@
-use std::collections::{BTreeSet, HashSet};
-use std::io;
+use std::{collections::BTreeSet, io};
 
-use crate::{
-  structure::entity::RTPSEntity,
-  dds::{
-    data_types::{DDSTimestamp, GUID, EntityId},
-    writer::Writer as RtpsWriter,
-    ddsdata::DDSData,
-  },
-  messages::header::Header,
-  messages::submessages::submessages::*,
-  messages::submessages::{
-    submessage::EntitySubmessage,
-    submessages::SubmessageKind,
-    submessage_elements::{parameter::Parameter, parameter_list::ParameterList},
-    submessage_elements::serialized_payload::RepresentationIdentifier,
-  },
-  messages::{protocol_version::ProtocolVersion, vendor_id::VendorId, protocol_id::ProtocolId},
-  serialization::submessage::{SubMessage, SubmessageBody},
-  structure::{
-    sequence_number::SequenceNumber,
-    sequence_number::SequenceNumberSet,
-    guid::{GuidPrefix, EntityKind},
-    cache_change::{CacheChange},
-    parameter_id::ParameterId,
-  },
-  structure::time::Timestamp,
-};
 #[allow(unused_imports)]
-use log::{error, warn, debug, trace};
-
-use speedy::{Readable, Writable, Endianness, Context, Writer};
+use log::{debug, error, trace, warn};
+use speedy::{Context, Endianness, Readable, Writable, Writer};
 use enumflags2::BitFlags;
 use bytes::Bytes;
 
+use crate::{
+  dds::{
+    data_types::{DDSTimestamp, EntityId, GUID},
+    ddsdata::DDSData,
+    writer::Writer as RtpsWriter,
+  },
+  messages::{
+    header::Header,
+    protocol_id::ProtocolId,
+    protocol_version::ProtocolVersion,
+    submessages::{
+      submessage::EntitySubmessage,
+      submessage_elements::{
+        parameter::Parameter, parameter_list::ParameterList,
+        serialized_payload::RepresentationIdentifier,
+      },
+      submessages::{SubmessageKind, *},
+    },
+    vendor_id::VendorId,
+  },
+  serialization::submessage::{SubMessage, SubmessageBody},
+  structure::{
+    cache_change::CacheChange,
+    entity::RTPSEntity,
+    guid::{EntityKind, GuidPrefix},
+    parameter_id::ParameterId,
+    sequence_number::{SequenceNumber, SequenceNumberSet},
+    time::Timestamp,
+  },
+};
+
 #[derive(Debug, Clone)]
 pub(crate) struct Message {
   pub header: Header,
@@ -41,45 +44,47 @@ pub(crate) struct Message {
 }
 
 impl<'a> Message {
-  pub fn deserialize_header(context: Endianness, buffer: &'a [u8]) -> Header {
-    Header::read_from_buffer_with_ctx(context, buffer).unwrap()
-  }
+  // pub fn deserialize_header(context: Endianness, buffer: &'a [u8]) -> Header {
+  //   Header::read_from_buffer_with_ctx(context, buffer).unwrap()
+  // }
 
-  pub fn serialize_header(self) -> Vec<u8> {
-    let buffer = self.header.write_to_vec_with_ctx(Endianness::LittleEndian);
-    buffer.unwrap()
-  }
+  // pub fn serialize_header(self) -> Vec<u8> {
+  //   let buffer = self.header.write_to_vec_with_ctx(Endianness::LittleEndian);
+  //   buffer.unwrap()
+  // }
 
   pub fn add_submessage(&mut self, submessage: SubMessage) {
     self.submessages.push(submessage);
   }
 
-  pub fn remove_submessage(mut self, index: usize) {
-    self.submessages.remove(index);
-  }
+  // pub fn remove_submessage(mut self, index: usize) {
+  //   self.submessages.remove(index);
+  // }
 
+  #[cfg(test)]
   pub fn submessages(self) -> Vec<SubMessage> {
     self.submessages
   }
 
+  #[cfg(test)]
   pub fn set_header(&mut self, header: Header) {
     self.header = header;
   }
 
-  pub fn get_data_sub_message_sequence_numbers(&self) -> HashSet<SequenceNumber> {
-    let mut sequence_numbers = HashSet::new();
-    for mes in self.submessages.iter() {
-      if let SubmessageBody::Entity(EntitySubmessage::Data(data_subm, _)) = &mes.body {
-        sequence_numbers.insert(data_subm.writer_sn);
-      }
-    }
-    sequence_numbers
-  }
+  // pub fn get_data_sub_message_sequence_numbers(&self) ->
+  // HashSet<SequenceNumber> {   let mut sequence_numbers = HashSet::new();
+  //   for mes in self.submessages.iter() {
+  //     if let SubmessageBody::Entity(EntitySubmessage::Data(data_subm, _)) =
+  // &mes.body {       sequence_numbers.insert(data_subm.writer_sn);
+  //     }
+  //   }
+  //   sequence_numbers
+  // }
 
   // We implement this instead of Speedy trait Readable, because
   // we need to run-time decide which endianness we input. Speedy requires the
-  // top level to fix that. And there seems to be no reasonable way to change endianness.
-  // TODO: The error type should be something better
+  // top level to fix that. And there seems to be no reasonable way to change
+  // endianness. TODO: The error type should be something better
   pub fn read_from_buffer(buffer: Bytes) -> io::Result<Message> {
     // The Header deserializes the same
     let rtps_header =
@@ -111,8 +116,8 @@ impl<'a> Message {
         sub_header.content_length as usize
       };
 
-      // we have to use temporary variable new_submessages_left to avoid creating another
-      // submessages_left
+      // we have to use temporary variable new_submessages_left to avoid creating
+      // another submessages_left
       // let (sub_buffer, new_submessages_left) =
       //   submessages_left.split_at(sub_header_length + sub_content_length);
       // submessages_left = new_submessages_left;
@@ -263,7 +268,7 @@ impl Message {
 impl Default for Message {
   fn default() -> Self {
     Message {
-      header: Header::new(GuidPrefix::GUIDPREFIX_UNKNOWN),
+      header: Header::new(GuidPrefix::UNKNOWN),
       submessages: vec![],
     }
   }
@@ -315,8 +320,8 @@ impl MessageBuilder {
   }
 
   /// Argument Some(timestamp) means that a timestamp is sent.
-  /// Argument None means "invalidate", i.e. the previously sent InfoTimestamp submessage
-  /// no longer applies.
+  /// Argument None means "invalidate", i.e. the previously sent InfoTimestamp
+  /// submessage no longer applies.
   pub fn ts_msg(
     mut self,
     endianness: Endianness,
@@ -402,8 +407,8 @@ impl MessageBuilder {
           BitFlags::<DATA_Flags>::from_flag(DATA_Flags::InlineQos)
         }
       });
-    // TODO: This is stupid. There should be an easier way to get the submessage length
-    // than serializing it!
+    // TODO: This is stupid. There should be an easier way to get the submessage
+    // length than serializing it!
     let size = data_message
       .write_to_vec_with_ctx(endianness)
       .unwrap()
@@ -420,8 +425,8 @@ impl MessageBuilder {
     self
   }
 
-  // TODO: We should optimize this entire thing to allow long contiguous irrelevant set to be
-  // represented as start_sn +
+  // TODO: We should optimize this entire thing to allow long contiguous
+  // irrelevant set to be represented as start_sn +
   pub fn gap_msg(
     mut self,
     irrelevant_sns: BTreeSet<SequenceNumber>,
@@ -436,7 +441,7 @@ impl MessageBuilder {
         let gap_list = SequenceNumberSet::from_base_and_set(base, &irrelevant_sns);
         let gap = Gap {
           reader_id: reader_guid.entity_id,
-          writer_id: writer.get_entity_id(),
+          writer_id: writer.entity_id(),
           gap_start: base,
           gap_list,
         };
@@ -462,7 +467,7 @@ impl MessageBuilder {
 
     let heartbeat = Heartbeat {
       reader_id: reader_entityid,
-      writer_id: writer.get_entity_id(),
+      writer_id: writer.entity_id(),
       first_sn: first,
       last_sn: last,
       count: writer.heartbeat_message_counter,
@@ -501,14 +506,15 @@ impl MessageBuilder {
 #[cfg(test)]
 
 mod tests {
+  #![allow(non_snake_case)]
   use log::info;
+  use speedy::Writable;
 
   use super::*;
-  use speedy::{Writable};
 
   #[test]
 
-  fn RTPS_message_test_shapes_demo_message_deserialization() {
+  fn rtps_message_test_shapes_demo_message_deserialization() {
     // Data message should contain Shapetype values.
     // caprured with wireshark from shapes demo.
     // packet with INFO_DST, INFO_TS, DATA, HEARTBEAT
@@ -534,7 +540,7 @@ mod tests {
     assert_eq!(bits1, serialized);
   }
   #[test]
-  fn RTPS_message_test_shapes_demo_DataP() {
+  fn rtps_message_test_shapes_demo_DataP() {
     // / caprured with wireshark from shapes demo.
     // packet with DATA(p)
     let bits2 = Bytes::from_static(&[
@@ -573,7 +579,7 @@ mod tests {
   }
 
   #[test]
-  fn RTPS_message_test_shapes_demo_info_TS_dataP() {
+  fn rtps_message_test_shapes_demo_info_TS_dataP() {
     // caprured with wireshark from shapes demo.
     // rtps packet with info TS and Data(p)
     let bits1 = Bytes::from_static(&[
@@ -605,7 +611,7 @@ mod tests {
   }
 
   #[test]
-  fn RTPS_message_test_shapes_demo_info_TS_AckNack() {
+  fn rtps_message_test_shapes_demo_info_TS_AckNack() {
     // caprured with wireshark from shapes demo.
     // rtps packet with info TS three AckNacks
     let bits1 = Bytes::from_static(&[
@@ -631,7 +637,7 @@ mod tests {
   }
 
   #[test]
-  fn RTPS_message_info_ts_and_dataP() {
+  fn rtps_message_info_ts_and_dataP() {
     // caprured with wireshark from shapes demo.
     // rtps packet with info TS and data(p)
     let bits1 = Bytes::from_static(&[
@@ -663,11 +669,11 @@ mod tests {
   }
 
   #[test]
-  fn RTPS_message_infoDST_infoTS_Data_w_heartbeat() {
+  fn rtps_message_infoDST_infoTS_Data_w_heartbeat() {
     // caprured with wireshark from shapes demo.
     // rtps packet with InfoDST InfoTS Data(w) Heartbeat
-    // This datamessage serialized payload maybe contains topic name (square) and its type (shapetype)
-    // look https://www.omg.org/spec/DDSI-RTPS/2.3/PDF page 185
+    // This datamessage serialized payload maybe contains topic name (square) and
+    // its type (shapetype) look https://www.omg.org/spec/DDSI-RTPS/2.3/PDF page 185
     let bits1 = Bytes::from_static(&[
       0x52, 0x54, 0x50, 0x53, 0x02, 0x03, 0x01, 0x0f, 0x01, 0x0f, 0x99, 0x06, 0x78, 0x34, 0x00,
       0x00, 0x01, 0x00, 0x00, 0x00, 0x0e, 0x01, 0x0c, 0x00, 0x01, 0x03, 0x00, 0x0c, 0x29, 0x2d,
@@ -698,20 +704,20 @@ mod tests {
     let rtps = Message::read_from_buffer(bits1.clone()).unwrap();
     info!("{:?}", rtps);
 
-    let dataSubmessage = match &rtps.submessages[2] {
+    let data_submessage = match &rtps.submessages[2] {
       SubMessage {
         header: _,
         body: SubmessageBody::Entity(EntitySubmessage::Data(d, _flags)),
       } => d,
       wtf => panic!("Unexpected message structure {:?}", wtf),
     };
-    let serializedPayload = dataSubmessage
+    let serialized_payload = data_submessage
       .serialized_payload
       .as_ref()
       .unwrap()
       .value
       .clone();
-    info!("{:x?}", serializedPayload);
+    info!("{:x?}", serialized_payload);
 
     let serialized = Bytes::from(
       rtps
@@ -721,6 +727,6 @@ mod tests {
     assert_eq!(bits1, serialized);
   }
 
-  // removed case test_RTPS_submessage_flags_helper , as it was cut-and-paste from
-  // submessage_flag module - and obsoleted there.
+  // removed case test_RTPS_submessage_flags_helper , as it was cut-and-paste
+  // from submessage_flag module - and obsoleted there.
 }
